---
title: "Examples"
---

This section is devoted to demonstrating of `matplotlib` and `seaborn` using the `profiplots`.

- [Basic Examples](basic.qmd): demonstrates simple plots with Profi Plots package.
- Advanced: WIP.
